# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.agent import Agent

class TestAgent(unittest.TestCase):
    """Agent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Agent:
        """Test Agent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Agent`
        """
        model = Agent()
        if include_optional:
            return Agent(
                name = '',
                data_plane_id = '',
                task_id = '',
                creation_source = None,
                model_id = '',
                num_spans = 56,
                is_autocreated = True,
                rules = [
                    arthur_client.api_bindings.models.rule_response.RuleResponse(
                        id = '', 
                        name = '', 
                        type = 'KeywordRule', 
                        apply_to_prompt = True, 
                        apply_to_response = True, 
                        enabled = True, 
                        scope = 'default', 
                        created_at = 56, 
                        updated_at = 56, 
                        config = null, )
                    ],
                last_fetched = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                muted_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                tools = [
                    arthur_client.api_bindings.models.tool.Tool(
                        name = '', 
                        arguments = [
                            arthur_client.api_bindings.models.tool_argument.ToolArgument(
                                name = '', 
                                type = '', )
                            ], )
                    ],
                sub_agents = [
                    arthur_client.api_bindings.models.sub_agent.SubAgent(
                        name = '', )
                    ],
                llm_models = [
                    arthur_client.api_bindings.models.llm_model.LLMModel(
                        name = '', )
                    ],
                data_sources = [
                    arthur_client.api_bindings.models.data_source.DataSource(
                        url = '', )
                    ]
            )
        else:
            return Agent(
                name = '',
                data_plane_id = '',
                task_id = '',
                creation_source = None,
        )
        """

    def testAgent(self):
        """Test Agent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
